pub fn null<'a, F, O>(parser: F) -> impl FnMut(ParseString<'a>)Expand description
Convert output of any parser into ParserNode::Null.
Useful for working with alt combinator and error recovery functions.
pub fn null<'a, F, O>(parser: F) -> impl FnMut(ParseString<'a>)Convert output of any parser into ParserNode::Null.
Useful for working with alt combinator and error recovery functions.